@@ -2,8 +2,8 @@
 __all__ = [
     # imio
     'array2nii', 'create_dir', 'dcm2im', 'dcm2nii', 'dcmanonym', 'dcminfo', 'dcmsort', 'fwhm2sig',
-    'getnii', 'getnii_descr', 'nii_gzip', 'nii_ugzip', 'niisort', 'orientnii', 'pick_t1w',
-    'time_stamp',
+    'mgh2nii', 'getmgh', 'getnii', 'getnii_descr', 'nii_gzip', 'nii_ugzip', 'niisort', 'orientnii',
+    'pick_t1w', 'time_stamp',
     # prc
     'bias_field_correction', 'centre_mass_img', 'centre_mass_corr', 'ct2mu', 'im_cut',
     'imsmooth', 'imtrimup',
@@ -26,8 +26,10 @@ from .imio import (
     dcminfo,
     dcmsort,
     fwhm2sig,
+    getmgh,
     getnii,
     getnii_descr,
+    mgh2nii,
     nii_gzip,
     nii_ugzip,
     niisort,
